==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/MultiValueLegacyExtendedProperty.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.EdmSchemaInfo;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "value"})
@JsonInclude(Include.NON_NULL)
public class MultiValueLegacyExtendedProperty extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.multiValueLegacyExtendedProperty";
    }

    @JsonProperty("value")
    protected List<String> value;

    @JsonProperty("value@nextLink")
    protected String valueNextLink;

    protected MultiValueLegacyExtendedProperty() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMultiValueLegacyExtendedProperty() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private List<String> value;
        private String valueNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder value(List<String> value) {
            this.value = value;
            this.changedFields = changedFields.add("value");
            return this;
        }

        public Builder value(String... value) {
            return value(Arrays.asList(value));
        }

        public Builder valueNextLink(String valueNextLink) {
            this.valueNextLink = valueNextLink;
            this.changedFields = changedFields.add("value");
            return this;
        }

        public MultiValueLegacyExtendedProperty build() {
            MultiValueLegacyExtendedProperty _x = new MultiValueLegacyExtendedProperty();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.multiValueLegacyExtendedProperty";
            _x.id = id;
            _x.value = value;
            _x.valueNextLink = valueNextLink;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="value")
    @JsonIgnore
    public CollectionPage<String> getValue() {
        return new CollectionPage<String>(contextPath, String.class, value, Optional.ofNullable(valueNextLink), EdmSchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="value")
    @JsonIgnore
    public CollectionPage<String> getValue(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, value, Optional.ofNullable(valueNextLink), EdmSchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MultiValueLegacyExtendedProperty patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        MultiValueLegacyExtendedProperty _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MultiValueLegacyExtendedProperty put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        MultiValueLegacyExtendedProperty _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private MultiValueLegacyExtendedProperty _copy() {
        MultiValueLegacyExtendedProperty _x = new MultiValueLegacyExtendedProperty();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.value = value;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MultiValueLegacyExtendedProperty[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("value=");
        b.append(this.value);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/MultiValueLegacyExtendedProperty.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "value"})
@JsonInclude(Include.NON_NULL)
public class MultiValueLegacyExtendedProperty extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.multiValueLegacyExtendedProperty";
    }

    @JsonProperty("value")
    protected List<String> value;

    @JsonProperty("value@nextLink")
    protected String valueNextLink;

    protected MultiValueLegacyExtendedProperty() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMultiValueLegacyExtendedProperty() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private List<String> value;
        private String valueNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder value(List<String> value) {
            this.value = value;
            this.changedFields = changedFields.add("value");
            return this;
        }

        public Builder value(String... value) {
            return value(Arrays.asList(value));
        }

        public Builder valueNextLink(String valueNextLink) {
            this.valueNextLink = valueNextLink;
            this.changedFields = changedFields.add("value");
            return this;
        }

        public MultiValueLegacyExtendedProperty build() {
            MultiValueLegacyExtendedProperty _x = new MultiValueLegacyExtendedProperty();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.multiValueLegacyExtendedProperty";
            _x.id = id;
            _x.value = value;
            _x.valueNextLink = valueNextLink;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="value")
    @JsonIgnore
    public CollectionPage<String> getValue() {
        return new CollectionPage<String>(contextPath, String.class, this.value, Optional.ofNullable(valueNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    public MultiValueLegacyExtendedProperty withValue(List<String> value) {
        MultiValueLegacyExtendedProperty _x = _copy();
        _x.changedFields = changedFields.add("value");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.multiValueLegacyExtendedProperty");
        _x.value = value;
        return _x;
    }

    @Property(name="value")
    @JsonIgnore
    public CollectionPage<String> getValue(HttpRequestOptions options) {
        return new CollectionPage<String>(contextPath, String.class, this.value, Optional.ofNullable(valueNextLink), Collections.emptyList(), options);
    }

    public MultiValueLegacyExtendedProperty withUnmappedField(String name, Object value) {
        MultiValueLegacyExtendedProperty _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MultiValueLegacyExtendedProperty patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        MultiValueLegacyExtendedProperty _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MultiValueLegacyExtendedProperty put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        MultiValueLegacyExtendedProperty _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private MultiValueLegacyExtendedProperty _copy() {
        MultiValueLegacyExtendedProperty _x = new MultiValueLegacyExtendedProperty();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.value = value;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MultiValueLegacyExtendedProperty[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("value=");
        b.append(this.value);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
